Documentation
¶
Index ¶
Constants ¶
const ( // ErrorInvalidWidth is string representation of the error returned // when the function is called with an empty string ErrorInvalidWidth = "invalid width" // ErrorEmptyString is string representatino of the error returned // when there are one or more invalid txt_width tag in the struct ErrorEmptyString = "string is empty" // ErrorEmptyStruct is string representation of the error returned // when marshal is called with an empty struct ErrorEmptyStruct = "struct is empty" )
Variables ¶
This section is empty.
Functions ¶
func Marshal ¶
Marshal is a function to marshal struct into string of fixed width determined by the struct tag
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.